@@ -9,7 +9,7 @@ except ImportError:  # pragma: no cover
     from monotonic import monotonic
 import concurrent.futures
 from collections import defaultdict
-from six.moves.queue import Queue, Full, Empty
+from queue import Queue, Full, Empty
 
 
 from .errors import PhaseInterrupted
